@@ -27,7 +27,8 @@ import (
 )
 
 type Config struct {
-	Images *Images `json:"-"`
+	Images   *Images               `json:"-"`
+	Platform configv1.PlatformType `json:"-"`
 
 	PrometheusOperatorConfig             *PrometheusOperatorConfig `json:"prometheusOperator"`
 	PrometheusOperatorUserWorkloadConfig *PrometheusOperatorConfig `json:"prometheusOperatorUserWorkload"`
@@ -308,6 +309,15 @@ func (c *Config) LoadProxy(load func() (*configv1.Proxy, error)) error {
 	return nil
 }
 
+func (c *Config) LoadPlatform(load func() (*configv1.Infrastructure, error)) error {
+	i, err := load()
+	if err != nil {
+		return fmt.Errorf("error loading platform: %v", err)
+	}
+	c.Platform = i.Status.Platform
+	return nil
+}
+
 func NewConfigFromString(content string) (*Config, error) {
 	if content == "" {
 		return NewDefaultConfig(), nil
